@@ -29,7 +29,7 @@ class HMPBase(ModuleExtension):
             result = self.derivatives.jac_t_mat_prod(module, g_inp, g_out, result)
 
             # Multiply with the residual term: mat → [∑ᵢ Hzᵢ(x) δzᵢ] mat.
-            if not self.derivatives.hessian_is_zero():
+            if not self.derivatives.hessian_is_zero(module):
                 result += self.derivatives.residual_mat_prod(module, g_inp, g_out, mat)
 
             return result
