@@ -1,6 +1,6 @@
-"""Test configurations to test diag_h
+"""Test configurations to test diag_h.
 
-The tests are taken from `test.extensions.secondorder.secondorder_settings`, 
+The tests are taken from `test.extensions.secondorder.secondorder_settings`,
 but additional custom tests can be defined here by appending it to the list.
 """
 
@@ -15,4 +15,5 @@ SHARED_SETTINGS = SECONDORDER_SETTINGS
 LOCAL_SETTINGS = []
 LOCAL_SETTINGS.append(make_simple_act_setting(LogSigmoid, bias=True))
 LOCAL_SETTINGS.append(make_simple_act_setting(LogSigmoid, bias=False))
+
 DiagHESSIAN_SETTINGS = SHARED_SETTINGS + LOCAL_SETTINGS
