@@ -5,6 +5,8 @@ Failure cases include
 - using unsupported parameters of the loss
 """
 
+from test.core.derivatives.utils import classification_targets
+
 import pytest
 import torch
 from torch.nn import CrossEntropyLoss, MSELoss
@@ -29,15 +31,10 @@ ext_2nd_order_name = [
 ]
 
 
-def classification_targets(N, num_classes):
-    """Create random targets for classes 0, ..., `num_classes - 1`."""
-    return torch.randint(size=(N,), low=0, high=num_classes)
-
-
 def dummy_cross_entropy(N=5):
     y_pred = torch.rand((N, 2))
     y_pred.requires_grad = True
-    y = classification_targets(N, 2)
+    y = classification_targets((N,), 2)
     loss_module = extend(CrossEntropyLoss())
     return loss_module(y_pred, y)
 
